@@ -16,7 +16,11 @@ RADIO_TIME_PRESET_ACTION_URL = 'http://opml.radiotime.com/Preset.ashx?c=%s&%s'
 RADIO_TIME_REPORT_URL = 'http://opml.radiotime.com/Report.ashx?c=wizard&%s'
 
 def getMacAddress():
-    if sys.platform == 'win32':
+    mac = '00:00:00:00:00:00'
+    if os.path.isfile('/usr/bin/sysinfo-tool'):
+        import commands
+        mac = commands.getoutput('sysinfo-tool -g /certs/npc/esn/wlan_id')
+    elif sys.platform == 'win32':
         for line in os.popen("ipconfig /all"):
             if line.lstrip().startswith('Physical Address'):
                mac = line.split(':')[1].strip().replace('-',':')
@@ -110,8 +114,12 @@ class SearchWindow(QMainWindow, Ui_SearchWindow):
         self.doSearch(url, 'Add', 'add', 'Search Results')
         
     def on_pushButtonPresets_released(self):
-        url = RADIO_TIME_PRESETS_URL % (self.serial)
-        self.doSearch(url, 'Remove', 'remove', 'My Presets')
+        if self.serial == '00:00:00:00:00:00':
+            QMessageBox.information(self, self.tr("Preset Status"), self.tr("Unique ID not found. Presets unavailable."))
+            self.pushButtonPresets.setEnabled(False)
+        else:
+            url = RADIO_TIME_PRESETS_URL % (self.serial)
+            self.doSearch(url, 'Remove', 'remove', 'My Presets')
 
 class ResultsWindow(QMainWindow, Ui_ResultsWindow):
 
